@@ -12,10 +12,12 @@ from wsgi_tracer.mapper import tree2list
 
 def profile_fn(fn, sample_filter=lambda x: x, sample_mapper=lambda x: x):
     profile = Profiler()
-    profile.start()
-    ret = fn()
-    profile.stop()
-    sample_data = json.loads(JSONRenderer().render(session=profile.last_session))
+    with profile:
+        ret = fn()
+    try:
+        sample_data = json.loads(JSONRenderer().render(session=profile.last_session))
+    except AssertionError as e:
+        return ret, {}
     sample_data['root_frame'] = sample_filter(sample_mapper(sample_data['root_frame']))
     return ret, sample_data
 
@@ -38,10 +40,8 @@ def wsgi_wrapper(
         sample_mapper,
         wsgi
 ):
-
-    if hasattr(wsgi, 'origin'):
-        return wsgi
-
+    # if hasattr(wsgi, 'origin'):
+    #     return wsgi
     @wraps(wsgi)
     def _(environ, resp, *args, **kwargs):
         _.origin = wsgi
@@ -73,12 +73,12 @@ def wsgi_wrapper(
 
 
 def trace_wsgi(worker, sample_rate=1, sample_filter=lambda x: x, sample_mapper=tree2list):
-    worker.wsgi.wsgi_app = wsgi_wrapper(
+    worker.wsgi = wsgi_wrapper(
         worker,
         sample_rate,
         sample_filter,
         sample_mapper,
-        worker.wsgi.wsgi_app,
+        worker.wsgi,
     )
 
 
